==> fastor_app_ui_widget-0.0.47.tar.gz: lib/resource/template/page/PageTemplate.dart <==


import 'package:easy_localization/easy_localization.dart';
import 'package:fastor_app_ui_widget/resource/template/image/ImageView.dart';
import 'package:fastor_app_ui_widget/resource/toolsFastor/device/DeviceTools.dart';



import 'package:flutter/material.dart';

import 'package:fastor_app_ui_widget/resource/template/progressView/ProgressPage.dart';

import 'package:fastor_app_ui_widget/fastor_app_ui_widget.dart';

import 'package:fastor_app_ui_widget/resource/ds/DesignSystemColor.dart';
import 'package:fastor_app_ui_widget/resource/template/emptyView/EmptyView.dart';

import 'package:fastor_app_ui_widget/resource/template/scrollview/ScrollViewPage.dart';


import 'base/BasePageTemplateProgrees.dart';

class PageTemplate {

  static const tag = "PageTemplate";

  //------------------------------------------------------------------------ type : Scaffold

  static Widget scaf (
      BuildContext context,
      {

        //body
        required Widget content,

        //page info
        String? title = "",  //page title show when app be at recent apps in android,
        //page title show at tab of new page in "Web"

        //background
        AssetImage? assetBackground, //image set to background of page pages "AssetImage"
        double? assetBackgroundOpacity,
        Color? colorBackground,

        //toolbar (top view )
        Widget? toolbar,
        double? toolbar_height ,

        //float_bottom ( bottom view )
        Widget? floatBottom,

        //  navigation: is the fixed view at align parent bottom of screen
        Widget? navigationBottom ,
        double? navigationBottom_height ,

        /**
         * TODO? need to do this in future
         */
        //footer
        Widget? footer,             //the footer  used at web
        double? footer_height,


        //progress
        ValueChanged<ProgressCircleState>? onChangeProgressState,

        //status
        HexColor? statusBarColorCustome,

        //drawer menu
        Widget? drawer,
        DrawerCallback? onDrawerChanged

      }){


    // check null
    title ??= "";
    title = title.tr();

    //step 1 - toolbar height
    if( toolbar != null ){
      toolbar_height ??= 70;
    }

    //step 2 - toolbar view
    toolbar ??= EmptyView.zero();

    //set default navigation height
    if( navigationBottom != null ) {
      navigationBottom_height ??= 70;
    }

    //navigation view
    navigationBottom ??= EmptyView.zero();

    //floatBottom view
    floatBottom ??= EmptyView.zero();

    //background (color or image )
    var myBackground = _getBackground( context, colorBackground, assetBackground, assetBackgroundOpacity );

    //scroll all page
    Widget scrollAllPage = ScrollViewPage.t( context, content,
        toolbarHeight: toolbar_height,
        footer_height: navigationBottom_height );

    // choose stack of page mobile app
    Stack stack = _putEveryBarToStack(context, myBackground, scrollAllPage, floatBottom,
        navigationBottom, navigationBottom_height,
        toolbar, onChangeProgressState );

    var pageStack =  _surroundPageStack(context, stack, title , statusBarColorCustome);

    return Scaffold( body: pageStack,
    drawer: drawer,
        onDrawerChanged: onDrawerChanged);
  }


  //------------------------------------------------------------------------ type : template

  static Widget t (
      BuildContext context,
      {

        //body
        required Widget content,

        //page info
        String? title = "",  //page title show when app be at recent apps in android,
        //page title show at tab of new page in "Web"

        //background
        AssetImage? assetBackground, //image set to background of page pages "AssetImage"
        double? assetBackgroundOpacity,
        Color? colorBackground,

        //toolbar (top view )
        Widget? toolbar,
        double? toolbar_height ,

        //float_bottom ( bottom view )
        Widget? floatBottom,

        //  navigation: is the fixed view at align parent bottom of screen
        Widget? navigationBottom ,
        double? navigationBottom_height ,

        /**
         * TODO? need to do this in future
         */
        //footer
        Widget? footer,             //the footer  used at web
        double? footer_height,


        //progress
        ValueChanged<ProgressCircleState>? onChangeProgressState,

        //status
        HexColor? statusBarColorCustome,

      }){


    // check null
    title ??= "";
    title = title.tr();

    //step 1 - toolbar height
    if( toolbar != null ){
      toolbar_height ??= 70;
    }

    //step 2 - toolbar view
    toolbar ??= EmptyView.zero();

    //set default navigation height
    if( navigationBottom != null ) {
      navigationBottom_height ??= 70;
    }

    //navigation view
    navigationBottom ??= EmptyView.zero();

    //floatBottom view
    floatBottom ??= EmptyView.zero();

    //background (color or image )
    var myBackground = _getBackground( context, colorBackground, assetBackground, assetBackgroundOpacity );

    //scroll all page
    Widget scrollAllPage = ScrollViewPage.t( context, content,
        toolbarHeight: toolbar_height,
        footer_height: navigationBottom_height );

    // choose stack of page mobile app
    Stack stack = _putEveryBarToStack(context, myBackground, scrollAllPage, floatBottom,
        navigationBottom, navigationBottom_height,
        toolbar, onChangeProgressState );

    var pageStack =  _surroundPageStack(context, stack, title , statusBarColorCustome);

    return pageStack;
  }

  //--------------------------------------------------------------- basic

  //+++++++++++++++++++++++ background

  static Widget _getBackground( BuildContext context, Color? colorBackground, AssetImage? assetBackground, double? assetBackgroundOpacity) {

    //color background
    colorBackground ??= DSColor.ds_background_all_screen;

    //set default background ( color or image )
    var myBackground =  EmptyView.colored(
        DeviceTools.getWidth( context),
        DeviceTools.getHeight(context ),
        colorBackground);

    // Log.i( "PagTemplate - DeviceTools.getWidth() " + DeviceTools.getWidth().toString() );

    if( assetBackground != null ) {
      //myBackground =   ImageBackground.allDeviceScreen( assetBackground , opacity: assetBackgroundOpacity!);
      myBackground = ImageView(
        width: DeviceTools.getWidth( context),
        height: DeviceTools.getHeight(  context ),
        opacity: assetBackgroundOpacity,
        colorBackground: colorBackground,
        assetBackground: assetBackground,
      );
    }

    return myBackground;
  }

  //--------------------------------------------------------------------- surround

  static Widget _surroundPageStack(BuildContext context, Stack stack, String? title, HexColor? statusBarColorCustome) {
    //
    var statusBarMobile = Colors.transparent; //website not need
    if( DeviceTools.isMobile() ) {

      //custome color mobile
      var mobileStatus  = statusBarColorCustome ;

      //default mobile
      mobileStatus  ??= StatusBarConstant.colorBackground;

      //set result
      statusBarMobile = mobileStatus;
    }

    //
    double marginStatusBar = 0;
    if( DeviceTools.isMobile() ) {
      marginStatusBar = StatusBarConstant.getHeight( context);
    }

    //status bar mobile
    var statusBar = Container(
      color: statusBarMobile , // StatusBarConstant.colorBackground, //statusBarMobile , // HexColor("#D486A8"),  //
      alignment: Alignment.topLeft,
      padding: EdgeInsets.only(
          top: marginStatusBar
      ),
      child: stack,
    );


    //material
    var material =  MaterialApp(
        title: title!,// "Home",
        debugShowCheckedModeBanner: false,
        home: statusBar);
    return material;
  }

  //------------------------------------------------------------------------ chosse page

  static Stack _putEveryBarToStack(
      BuildContext context,
      Widget myBackground,
      Widget scrollAllPage,
      Widget floatBottom,
      Widget navigationBottom,
      double? navigation_height,
      Widget toolbar,
      ValueChanged<ProgressCircleState>? onChangeProgressState) {


    //progress
    var progress = BasePageTemplateProgress.progressView(onChangeProgressState);

    // var statusBarHeight = StatusBarConstant.getHeight();

    var stack =  Stack(
      children: [

        //expanded
        EmptyView.allDeviceScreen(context),

        //set image to background
        myBackground,

        //scroll here
        scrollAllPage,

        //progress center
        Align( child: progress , alignment: Alignment.center ),

        // floating
        Positioned(child: floatBottom, bottom: 0, left: 0, right: 0 ),

        //toolbar fixed at top of the view
        toolbar,

        // navigation
        Positioned(child: navigationBottom, bottom: 0, left: 0, right: 0 ),

        //test
        // Text( "4: " + StatusBarConstant.colorBackground.hexColor )

      ],
    );

    return stack;
  }




}

==> fastor_app_ui_widget-0.0.56.tar.gz: lib/resource/template/page/PageTemplate.dart <==


import 'package:easy_localization/easy_localization.dart';
import 'package:fastor_app_ui_widget/resource/template/image/ImageView.dart';
import 'package:fastor_app_ui_widget/resource/toolsFastor/device/DeviceTools.dart';



import 'package:flutter/material.dart';

import 'package:fastor_app_ui_widget/resource/template/progressView/ProgressPage.dart';

import 'package:fastor_app_ui_widget/fastor_app_ui_widget.dart';

import 'package:fastor_app_ui_widget/resource/ds/DesignSystemColor.dart';
import 'package:fastor_app_ui_widget/resource/template/emptyView/EmptyView.dart';

import 'package:fastor_app_ui_widget/resource/template/scrollview/ScrollViewPage.dart';


import 'base/BasePageTemplateProgrees.dart';

class PageTemplate {

  static const tag = "PageTemplate";

  //------------------------------------------------------------------------ type : Scaffold

  static Widget t (
      BuildContext context,
      {

        //body
        required Widget content,

        //page info
        String? title = "",  //page title show when app be at recent apps in android,
        //page title show at tab of new page in "Web"

        //background
        AssetImage? assetBackground, //image set to background of page pages "AssetImage"
        double? assetBackgroundOpacity,
        Color? colorBackground,

        //toolbar (top view )
        Widget? toolbar,
        double? toolbar_height ,

        //float_bottom ( bottom view )
        Widget? floatBottom,

        //  navigation: is the fixed view at align parent bottom of screen
        Widget? navigationBottom ,
        double? navigationBottom_height ,

        /**
         * TODO? need to do this in future
         */
        //footer
        Widget? footer,             //the footer  used at web
        double? footer_height,


        //progress
        ValueChanged<ProgressCircleState>? onChangeProgressState,

        //status
        HexColor? statusBarColorCustome,

        //drawer menu
        GlobalKey? scaffoldKey, // = GlobalKey()
        Widget? drawer,
        DrawerCallback? onDrawerChanged,

        //scroll
        ScrollController? scrollController
      }){


    // check null
    title ??= "";
    title = title.tr();

    //step 1 - toolbar height
    if( toolbar != null ){
      toolbar_height ??= 70;
    }

    //step 2 - toolbar view
    toolbar ??= EmptyView.zero();

    //set default navigation height
    if( navigationBottom != null ) {
      navigationBottom_height ??= 70;
    }

    //navigation view
    navigationBottom ??= EmptyView.zero();

    //floatBottom view
    floatBottom ??= EmptyView.zero();

    //background (color or image )
    var myBackground = _getBackground( context, colorBackground, assetBackground, assetBackgroundOpacity );

    //scroll all page
    Widget scrollAllPage = ScrollViewPage.t( context, content,
        scrollController: scrollController,
        toolbarHeight: toolbar_height,
        footer_height: navigationBottom_height );

    // choose stack of page mobile app
    Stack stack = _putEveryBarToStack(context, myBackground, scrollAllPage, floatBottom,
        navigationBottom, navigationBottom_height,
        toolbar, onChangeProgressState );

    var pageStack =  _surroundPageStack(context, stack, title , statusBarColorCustome);

    return Scaffold( body: pageStack,
    key:  scaffoldKey,
    drawer: drawer,
        onDrawerChanged: onDrawerChanged);
  }

  //--------------------------------------------------------------- basic

  //+++++++++++++++++++++++ background

  static Widget _getBackground( BuildContext context, Color? colorBackground, AssetImage? assetBackground, double? assetBackgroundOpacity) {

    //color background
    colorBackground ??= DSColor.ds_background_all_screen;

    //set default background ( color or image )
    var myBackground =  EmptyView.colored(
        DeviceTools.getWidth( context),
        DeviceTools.getHeight(context ),
        colorBackground);

    // Log.i( "PagTemplate - DeviceTools.getWidth() " + DeviceTools.getWidth().toString() );

    if( assetBackground != null ) {
      //myBackground =   ImageBackground.allDeviceScreen( assetBackground , opacity: assetBackgroundOpacity!);
      myBackground = ImageView(
        width: DeviceTools.getWidth( context),
        height: DeviceTools.getHeight(  context ),
        opacity: assetBackgroundOpacity,
        colorBackground: colorBackground,
        assetBackground: assetBackground,
      );
    }

    return myBackground;
  }

  //--------------------------------------------------------------------- surround

  static Widget _surroundPageStack(BuildContext context, Stack stack, String? title, HexColor? statusBarColorCustome) {
    //
    var statusBarMobile = Colors.transparent; //website not need
    if( DeviceTools.isMobile() ) {

      //custome color mobile
      var mobileStatus  = statusBarColorCustome ;

      //default mobile
      mobileStatus  ??= StatusBarConstant.colorBackground;

      //set result
      statusBarMobile = mobileStatus;
    }

    //
    double marginStatusBar = 0;
    if( DeviceTools.isMobile() ) {
      marginStatusBar = StatusBarConstant.getHeight( context);
    }

    //status bar mobile
    var statusBar = Container(
      color: statusBarMobile , // StatusBarConstant.colorBackground, //statusBarMobile , // HexColor("#D486A8"),  //
      alignment: Alignment.topLeft,
      padding: EdgeInsets.only(
          top: marginStatusBar
      ),
      child: stack,
    );


    //material
    var material =  MaterialApp(
        title: title!,// "Home",
        debugShowCheckedModeBanner: false,
        home: statusBar);
    return material;
  }

  //------------------------------------------------------------------------ chosse page

  static Stack _putEveryBarToStack(
      BuildContext context,
      Widget myBackground,
      Widget scrollAllPage,
      Widget floatBottom,
      Widget navigationBottom,
      double? navigation_height,
      Widget toolbar,
      ValueChanged<ProgressCircleState>? onChangeProgressState) {


    //progress
    var progress = BasePageTemplateProgress.progressView(onChangeProgressState);

    // var statusBarHeight = StatusBarConstant.getHeight();

    var stack =  Stack(
      children: [

        //expanded
        EmptyView.allDeviceScreen(context),

        //set image to background
        myBackground,

        //scroll here
        scrollAllPage,

        //progress center
        Align( child: progress , alignment: Alignment.center ),

        // floating
        Positioned(child: floatBottom, bottom: 0, left: 0, right: 0 ),

        //toolbar fixed at top of the view
        toolbar,

        // navigation
        Positioned(child: navigationBottom, bottom: 0, left: 0, right: 0 ),

        //test
        // Text( "4: " + StatusBarConstant.colorBackground.hexColor )

      ],
    );

    return stack;
  }




}
